commit

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2026 License: MIT Imports: 4 Imported by: 0

Documentation

Overview

Package commit parses conventional commit messages into structured data with type, scope, breaking flag, and Jira keys.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Commit

type Commit struct {
	Hash         string
	Author       string
	Email        string
	Timestamp    time.Time
	Type         string
	Scope        string
	Breaking     bool
	Header       string
	RawHeader    string
	Body         string
	Footer       string
	ChangedFiles int
	JiraKeys     []string
	Significance string
	ClassReason  string
}

func Parse

func Parse(raw RawCommit) Commit

type RawCommit

type RawCommit struct {
	Hash      string
	Author    string
	Email     string
	Timestamp time.Time
	Message   string
}

Jump to