package
Version:
v0.1.1
Opens a new window with list of versions in this module.
Published: Jul 22, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package infer uses AI to classify uncategorized commits into conventional commit types.
type Result struct {
Hash string `json:"hash"`
Type string `json:"type"`
Confidence float64 `json:"confidence"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.