jira

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 23, 2026 License: MIT Imports: 13 Imported by: 0

Documentation

Overview

Package jira provides a Jira Cloud/Server API client for fetching issue details concurrently with caching support.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ExtractKeys

func ExtractKeys(text string) []string

Types

type Client

type Client struct {
	// contains filtered or unexported fields
}

Client is a Jira API client with caching and concurrent fetching.

func NewClient

func NewClient(cfg Config) *Client

func (*Client) Configured

func (c *Client) Configured() bool

func (*Client) EnrichKeys

func (c *Client) EnrichKeys(ctx context.Context, keys []string) map[string]*Issue

func (*Client) FetchIssue

func (c *Client) FetchIssue(ctx context.Context, key string) (*Issue, error)

func (*Client) FilterKeys

func (c *Client) FilterKeys(keys []string) []string

func (*Client) SearchByFixVersion

func (c *Client) SearchByFixVersion(ctx context.Context, projectKey, fixVersion string) ([]*Issue, error)

func (*Client) SetCache

func (c *Client) SetCache(fc *cache.Cache)

type Config

type Config struct {
	BaseURL        string `yaml:"base_url"`
	Email          string `yaml:"email"`
	APIToken       string `yaml:"api_token"`
	ProjectKey     string `yaml:"project_key"`
	MaxConcurrency int    `yaml:"max_concurrency"`
}

type Issue

type Issue struct {
	Key         string   `json:"key"`
	Summary     string   `json:"summary"`
	Priority    string   `json:"priority"`
	Status      string   `json:"status"`
	Type        string   `json:"type"`
	Labels      []string `json:"labels"`
	URL         string   `json:"url"`
	EpicKey     string   `json:"epic_key"`
	FixVersions []string `json:"fix_versions"`
	Components  []string `json:"components"`
	Description string   `json:"description"`
	Assignee    string   `json:"assignee"`
}

Issue holds enriched Jira ticket data for release notes.

Jump to