Documentation
¶
Overview ¶
Package jira provides a Jira Cloud/Server API client for fetching issue details concurrently with caching support.
Index ¶
- func ExtractKeys(text string) []string
- type Client
- func (c *Client) Configured() bool
- func (c *Client) EnrichKeys(ctx context.Context, keys []string) map[string]*Issue
- func (c *Client) FetchIssue(ctx context.Context, key string) (*Issue, error)
- func (c *Client) FilterKeys(keys []string) []string
- func (c *Client) SearchByFixVersion(ctx context.Context, projectKey, fixVersion string) ([]*Issue, error)
- func (c *Client) SetCache(fc *cache.Cache)
- type Config
- type Issue
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ExtractKeys ¶
Types ¶
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
Client is a Jira API client with caching and concurrent fetching.
func (*Client) Configured ¶
func (*Client) EnrichKeys ¶
func (*Client) FetchIssue ¶
func (*Client) FilterKeys ¶
func (*Client) SearchByFixVersion ¶
type Issue ¶
type Issue struct {
Key string `json:"key"`
Summary string `json:"summary"`
Priority string `json:"priority"`
Status string `json:"status"`
Type string `json:"type"`
Labels []string `json:"labels"`
URL string `json:"url"`
EpicKey string `json:"epic_key"`
FixVersions []string `json:"fix_versions"`
Components []string `json:"components"`
Description string `json:"description"`
Assignee string `json:"assignee"`
}
Issue holds enriched Jira ticket data for release notes.
Click to show internal directories.
Click to hide internal directories.